@@ -1,7 +1,7 @@
 import os
 import docker
 from .docker_util import docker_login, docker_pull_image, get_timestamp, save_stdout, save_stderr
-from .maven_util import find_m2_location
+from .java_repo_util import find_m2_location, find_gradle_location
 
 def run_sast_scanner(params):
     client = docker_login(params['scan_info'])
@@ -44,18 +44,26 @@ def run_sast_scanner(params):
 
     if scanner == 'findsecbugs':
         # check and pass in the m2 location
-        m2_location = ''
-        if 'JAVA_M2_PATH' in config['variables'] and config['variables']['JAVA_M2_PATH'] is not None:
-            m2_location = config['variables']['JAVA_M2_PATH']
+        external_location = ''
+        if 'MAVEN_REPO_PATH' in config['variables'] and config['variables']['MAVEN_REPO_PATH'] is not None:
+            external_location = config['variables']['MAVEN_REPO_PATH']
         else:
-            m2_location = find_m2_location()
+            external_location = find_m2_location()
 
-        if m2_location:
-            print('using m2 location: ' + m2_location)
+        external_location = ''
+        if not external_location:
+            # check and pass in the Gradle dependency cache location
+            if 'GRADLE_CACHE_PATH' in config['variables'] and config['variables']['GRADLE_CACHE_PATH'] is not None:
+                external_location = config['variables']['GRADLE_CACHE_PATH']
+            else:
+                external_location = find_gradle_location()
+
+        if external_location:
+            print('using external classes location: ' + external_location)
             container = client.containers.run(docker_image, '--externalCalss=1', volumes={
                 build_dir: {
                     'bind': '/scan', 'mode': 'rw'},
-                m2_location: {
+                external_location: {
                     'bind': '/class', 'mode': 'rw'}
                 }, detach=True, tty=False, stdout=True, stderr=True)
         else:
